summaryrefslogtreecommitdiffstats
path: root/core.h
diff options
context:
space:
mode:
authorMark Farrugia <mark.farrugia@fiberdyne.com.au>2018-10-25 17:37:07 +1100
committerMark Farrugia <mark.farrugia@fiberdyne.com.au>2018-10-26 17:27:50 +1100
commitd66dbf0820e9e7e14a6f723c1ce92b7ac4e0280d (patch)
treea63bb7dea2279c61cdfa52c78d3b889e6e0c8869 /core.h
parentd8ff159e37cb3768358b350b2dc80118d81d4b2c (diff)
Refactor all avirt_ symbols to have have snd prefix, as per Linux sound
This will aid the eventual migration the the upstream mainline Linux kernel Fix some checkpatch warnings, and other compiler warnings Signed-off-by: Mark Farrugia <mark.farrugia@fiberdyne.com.au>
Diffstat (limited to 'core.h')
-rw-r--r--core.h33
1 files changed, 18 insertions, 15 deletions
diff --git a/core.h b/core.h
index ca47067..735df65 100644
--- a/core.h
+++ b/core.h
@@ -14,7 +14,9 @@
#include "utils.h"
-struct avirt_core {
+extern struct snd_pcm_ops pcm_ops;
+
+struct snd_avirt_core {
struct snd_card *card;
struct device *dev;
struct class *avirt_class;
@@ -24,44 +26,45 @@ struct avirt_core {
};
/**
* __avirt_configfs_init - Initialise the configfs system
* @core: The avirt_core pointer
* @return: 0 on success, negative ERRNO on failure
*/
-int __init __avirt_configfs_init(struct avirt_core *core);
+int __init snd_avirt_configfs_init(struct snd_avirt_core *core);
/**
* __avirt_configfs_exit - Clean up and exit the configfs system
* @core: The avirt_core pointer
*/
-void __exit __avirt_configfs_exit(struct avirt_core *core);
+void __exit snd_avirt_configfs_exit(struct snd_avirt_core *core);
/**
* __avirt_streams_seal - Register the sound card to user space
* @return: 0 on success, negative ERRNO on failure
*/
-int __avirt_streams_seal(void);
+int snd_avirt_streams_seal(void);
/**
* __avirt_streams_sealed - Check whether the streams have been sealed or not
* @return: true if sealed, false otherwise
*/
-bool __avirt_streams_sealed(void);
+bool snd_avirt_streams_sealed(void);
/**
* __avirt_stream_find_by_device - Get audio stream from device number
* @device: The PCM device number corresponding to the desired stream
* @return: The audio stream if found, or an error pointer otherwise
*/
-struct avirt_stream *__avirt_stream_find_by_device(unsigned int device);
+struct snd_avirt_stream *snd_avirt_stream_find_by_device(unsigned int device);
/**
* __avirt_stream_create - Create audio stream, including it's ALSA PCM device
* @name: The name designated to the audio stream
* @direction: The PCM direction (SNDRV_PCM_STREAM_PLAYBACK or
* SNDRV_PCM_STREAM_CAPTURE)
* @return: The newly created audio stream if successful, or an error pointer
*/
-struct avirt_stream *__avirt_stream_create(const char *name, int direction);
+struct snd_avirt_stream *snd_avirt_stream_create(const char *name,
+ int direction);
#endif /* __SOUND_AVIRT_CORE_H */
@@ -24,44 +26,45 @@ struct avirt_core {
};
/**
- * __avirt_configfs_init - Initialise the configfs system
- * @core: The avirt_core pointer
+ * snd_avirt_configfs_init - Initialise the configfs system
+ * @core: The snd_avirt_core pointer
* @return: 0 on success, negative ERRNO on failure
*/
@@ -24,44 +26,45 @@ struct avirt_core {
/**
- * __avirt_configfs_exit - Clean up and exit the configfs system
- * @core: The avirt_core pointer
+ * snd_avirt_configfs_exit - Clean up and exit the configfs system
+ * @core: The snd_avirt_core pointer
*/
@@ -24,44 +26,45 @@ struct avirt_core {
/**
- * __avirt_streams_seal - Register the sound card to user space
+ * snd_avirt_streams_seal - Register the sound card to user space
* @return: 0 on success, negative ERRNO on failure
*/
@@ -24,44 +26,45 @@ struct avirt_core {
/**
- * __avirt_streams_sealed - Check whether the streams have been sealed or not
+ * snd_avirt_streams_sealed - Check if the streams have been sealed or not
* @return: true if sealed, false otherwise
*/
@@ -24,44 +26,45 @@ struct avirt_core {
/**
- * __avirt_stream_find_by_device - Get audio stream from device number
+ * snd_avirt_stream_find_by_device - Get audio stream from device number
* @device: The PCM device number corresponding to the desired stream
* @return: The audio stream if found, or an error pointer otherwise
@@ -24,44 +26,45 @@ struct avirt_core {
/**
- * __avirt_stream_create - Create audio stream, including it's ALSA PCM device
+ * snd_avirt_stream_create - Create audio stream, including it's ALSA PCM device
* @name: The name designated to the audio stream
* @direction: The PCM direction (SNDRV_PCM_STREAM_PLAYBACK or